# scripts

This directory contains scripts that wraps around `main.py`, `eval.py`, and `simulator.py`.

1. GPT
2. Gemini 
3. ollama

These scripts are provided for convenience and quick setup. It is much easier to use one of these models than to run your own with cuda.
